﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class GameScript : MonoBehaviour
{

    public List<GameObject> Packers;
    public int Score;
    public float BonusTime = 4.5f;
    public bool GameOver
    {
        get { return Time < 0.0f; }
    }

    public bool GameRunning;

    public float Time = 60.0f;

    private Text _textScore;
    private Text _textTime;

    private Text _instructionKeysText;

    private GameObject _gameOverPanel;
    private GameObject _gameStartPanel;

    private Spawner _mySpawner;

    private AudioSource _myAudioSource;

    public AudioClip[] DwarfSounds;

    bool[] dwarfInputs = { false, false, false, false, false, false, false };

    // Use this for initialization
    void Awake()
    {
        _textScore = GameObject.Find("TextScore").GetComponent<Text>();
        _textTime = GameObject.Find("TextTime").GetComponent<Text>();
        _gameOverPanel = GameObject.Find("Game Over Panel");
        _gameStartPanel = GameObject.Find("Start Panel");
        _mySpawner = GameObject.Find("SpawnPoint").GetComponent<Spawner>();
        _myAudioSource = GetComponent<AudioSource>();

        _instructionKeysText = GameObject.Find("Keys Text").GetComponent<Text>();
    }

    void Start()
    {
        GameRunning = false;
        _gameStartPanel.SetActive(true);
        _textScore.gameObject.transform.parent.gameObject.SetActive(false);
        _textTime.gameObject.transform.parent.gameObject.SetActive(false);
    }

    private void StartGame()
    {
        _gameStartPanel.SetActive(false);
        _textScore.gameObject.transform.parent.gameObject.SetActive(true);
        _textTime.gameObject.transform.parent.gameObject.SetActive(true);
        GameRunning = true;
        _mySpawner.StartSpawning();
    }

    string[] Keys = { "q", "w", "e", "r", "t", "z", "u" };
    // Update is called once per frame
    void Update()
    {
        _gameOverPanel.SetActive(GameOver);

        if (GameOver)
        {
            _gameOverPanel.SetActive(GameOver);
            return;
        }

        if (!GameRunning)
        {
            for (int x = 0; x < 7; x++) {
                if (Input.GetKeyDown(Keys[x] ))
                {
                    dwarfInputs[x] = true;
                }
            }

            _instructionKeysText.text = string.Empty;
            for (int x = 0; x < 7; x++)
            {
                if (dwarfInputs[x])
                {
                    _instructionKeysText.text += "<color='red'>[" + Keys[x] + "]</color> ";
                }
                else
                {
                    _instructionKeysText.text += "[" + Keys[x]+ "] ";
                }
            }

            if (dwarfInputs[0] && dwarfInputs[1] && dwarfInputs[2] && 
                dwarfInputs[3] && dwarfInputs[4] && dwarfInputs[5] && dwarfInputs[6])
            {
                StartGame();
            }

            return;
        }

        Time -= UnityEngine.Time.deltaTime;


        for (int i = 0; i < Packers.Count; i++)
        {
            if (Packers[i] != null)
            {
                Packers[i].GetComponent<LaolaScript>().Stretch = Input.GetButton("Packer" + (i + 1).ToString());

                if (Input.GetButtonDown("Packer" + (i + 1).ToString()))
                {
                    _myAudioSource.clip = DwarfSounds[Random.Range(0,DwarfSounds.Length -1)];
                    var dwarvenPitch = Random.Range(0.75f, 1.1f);
                    _myAudioSource.pitch = dwarvenPitch;
                    _myAudioSource.Play();
                    
                }

            }
        }
        _textScore.text = Score.ToString();
        _textTime.text = string.Format("{0:0}s", Mathf.CeilToInt(Time));
    }

    public void AddPointToScore()
    {
        Score++;
        Time += BonusTime;
    }
}
