﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class LaolaScript : MonoBehaviour
{
    public float StretchFactor = 0.10f;
    public bool Stretch = false;
    public Sprite PackerLow;
    public Sprite PackerMid;
    public Sprite PackerHigh;

    private EdgeCollider2D _edgeCollider;
    private PolygonCollider2D _polyCollider;
    private SpriteRenderer _spriteRenderer;

    private float _yScaleSwitchLowMid = 1.46f;
    private float _yScaleSwitchMidHigh = 1.49f;
    private float _yScaleMaxHigh = 1.0f;

    private float _colliderYOffsetLow = 0.0f;
    private float _colliderYOffsetMid = 0.84f;
    private float _colliderYOffsetHigh = 1.57f;


    // Use this for initialization
    void Awake()
    {
        _edgeCollider = GetComponent<EdgeCollider2D>();
        _polyCollider = GetComponent<PolygonCollider2D>();
        _spriteRenderer = GetComponent<SpriteRenderer>();
    }

    // Update is called once per frame
    void Update()
    {
        float scale = gameObject.transform.localScale.y;

        if (Stretch)
        {
            if (_spriteRenderer.sprite == PackerLow)
            {
                if (scale >= _yScaleSwitchLowMid)
                {
                    _spriteRenderer.sprite = PackerMid;
                    scale = 1.0f;
                    _edgeCollider.offset = new Vector2(0.0f, _colliderYOffsetMid);
                    _polyCollider.offset = new Vector2(0.0f, _colliderYOffsetMid);
                }
                else
                {
                    scale += StretchFactor * Time.deltaTime;
                }
            }
            if (_spriteRenderer.sprite == PackerMid)
            {
                if (scale >= _yScaleSwitchMidHigh)
                {
                    _spriteRenderer.sprite = PackerHigh;
                    scale = 1.0f;
                    _edgeCollider.offset = new Vector2(0.0f, _colliderYOffsetHigh);
                    _polyCollider.offset = new Vector2(0.0f, _colliderYOffsetHigh);
                }
                else
                {
                    scale += StretchFactor * Time.deltaTime;
                }
            }
            if (_spriteRenderer.sprite == PackerHigh)
            {
                if (scale < _yScaleMaxHigh)
                {
                    scale += StretchFactor * Time.deltaTime;
                    scale = Mathf.Min(scale, _yScaleMaxHigh);
                }
            }
        }
        else
        {
            if (_spriteRenderer.sprite == PackerHigh)
            {
                if (scale <= 1.0f)
                {
                    _spriteRenderer.sprite = PackerMid;
                    scale = _yScaleSwitchMidHigh;
                    _edgeCollider.offset = new Vector2(0.0f, _colliderYOffsetMid);
                    _polyCollider.offset = new Vector2(0.0f, _colliderYOffsetMid);
                }
                else
                {
                    scale -= StretchFactor * Time.deltaTime;
                    scale = Mathf.Max(scale, 1.0f);
                }
            }
            if (_spriteRenderer.sprite == PackerMid)
            {
                if (scale <= 1.0f)
                {
                    _spriteRenderer.sprite = PackerLow;
                    scale = _yScaleSwitchLowMid;
                    _edgeCollider.offset = new Vector2(0.0f, _colliderYOffsetLow);
                    _polyCollider.offset = new Vector2(0.0f, _colliderYOffsetLow);
                }
                else
                {
                    scale -= StretchFactor * Time.deltaTime;
                    scale = Mathf.Max(scale, 1.0f);
                }
            }
            if (_spriteRenderer.sprite == PackerLow)
            {
                if (scale > 1.0f)
                {
                    scale -= StretchFactor * Time.deltaTime;
                    scale = Mathf.Max(scale, 1.0f);
                }
            }
        }

        gameObject.transform.localScale = new Vector3(1.0f, scale, 1.0f);
    }
}
